
#ifndef CONFIG_H_
#define CONFIG_H_

#include "../../configure.h"
//SETS FULLSCREEN on/off  ...Must be TRUE for 800x480 resolutions
#define SET_FULLSCREEN FALSE

//USE JAMMOS CONFIGURATION.H
//#define PATH_DEVICE TRUE

#define PG_IMAGES_DIR DATA_DIR "/password";
#define PG_VERSION "v.0.7.1";

//FULL SCREEN  MESSAGES 300x200 QUE FONTita! 32px
#define PG_PASSWORD_ERROR "wrong_password.png"
#define PG_RESET_PASSWORD_ERROR "wrong_password_reset.png"
#define PG_RESET_PASSWORD_SUCCESS "valid_password_reset.png"

//SMALL MESSAGES 200x100 QUE FONTita! 32px
#define PG_RESET_PASSWD_MESSAGE "reset_passwd_msg.png"


//TEMPORARY 4 TESTING
#define MYJAMMERSOUNDPATH DATA_DIR "/pengesture_kling.ogg"

#endif /* CONFIG_H_ */



